\name{Cars2004}
\alias{Cars2004}
\alias{Cars2004nh}
\docType{data}
\title{2004 New car and truck data}
\description{
  Data on 428 new vehicles that were on the market in the U.S. in 2004.
  The variables recorded include price, measurements relating to the
  size of the vehicle, and fuel efficiency.

  Data \code{Cars2004nh} are a subset of \code{Cars2004} containing only
  cars with a non-hybrid engine.
}
\usage{
data(Cars2004)

data(Cars2004nh)
}
\format{
  A \code{data.frame} with 428 rows (425 rows for \code{Cars2004nh}) and the following variables.
  \describe{
    \item{vname}{vehicle name}
    \item{type}{type of the vehicle, 1 = \emph{personal}, 2 = \emph{wagon}, 3 =
      \emph{sport utility vehicle (SUV)}, 4 = \emph{pickup}, 5 =
      \emph{sports car}, 6 = \emph{minivan}}
    \item{drive}{drive of the vehicle, 1 = \emph{front-wheel}, 2 =
      \emph{rear-wheel}, 3 = \emph{all-wheel (4x4)}}
    \item{hybrid}{is this a hybrid (gas/electric) vehicle, 0 =
      \emph{no}, 1 = \emph{yes}, not present in \code{Cars2004nh}}
    \item{price.retail}{suggested retail price, what the manufacturer thinks the
		vehicle is worth, including adequate profit for the
		automaker and the dealer [USD]}
    \item{price.dealer}{dealer cost (or \dQuote{invoice price}), what the dealership pays
		the manufacturer [USD]}
    \item{price}{an average of \code{price.retail} and
      \code{price.dealer} [USD]}
    \item{cons.city}{city fuel consumption [liters/100 km]}
    \item{cons.highway}{highway fuel consumption [liters/100 km]}
    \item{consumption}{an average of \code{cons.city} and
      \code{cons.highway} [liters/100 km]}
    \item{engine.size}{engine size [liters]}
    \item{ncylinder}{number of cylinders, \eqn{-1} if rotary engine}
    \item{horsepower}{engine horsepower}
    \item{weight}{weight [kg]}
    \item{iweight}{reciprocal of the weight}
    \item{lweight}{natural logarithm of the weight}
    \item{wheel.base}{wheel base [cm]}
    \item{length}{length of the vehicle [cm]}
    \item{width}{width of the vehicle [cm]}
    \item{ftype}{\code{factor} with levels \emph{personal}/\emph{wagon}/\emph{SUV}/\emph{pickup}/\emph{sport}/\emph{minivan} corresponding to
      the variable \code{type}}
    \item{fdrive}{\code{factor} with levels \emph{front}/\emph{rear}/\emph{4x4} corresponding to
      the variable \code{drive}}
    \item{fhybrid}{\code{factor} with levels \emph{No}/\emph{Yes}
      corresponding to the variable \code{hybrid}, not present in \code{Cars2004nh}}    
  }  
}
\source{
  Kiplinger's Personal Finance, December 2003, vol. 57, no. 12,
  pp. 104-123,
  \url{http:/www.kiplinger.com}
  
  \url{http://www.amstat.org/publications/jse/datasets/04cars.dat.txt}

  Transformations from units used classically in the U.S. (miles per
  gallon, inches, pounds) into units used classically in the continental
  Europe (liters per 100 km, centimeters, kilograms) provided by the
  package author.
}
\examples{
data(Cars2004)
summary(Cars2004)

data(Cars2004nh)
summary(Cars2004nh)
}
\keyword{datasets}
