\name{Howells}
\alias{Howells}
\alias{HowellsAll}
\docType{data}
\title{W.W. Howells' craniometric data}
\description{
  Archaeological data on skulls.

  Original data are described in a paper Howells (1996). Subset of these
  original data presented here is also used
  for some illustrations in the book \emph{Regrese}
  by Karel Zvára (Zvára, 2008).

  Two measurements are provided here:
  (i) occipital angle (\emph{týlní úhel} in Czech),
  (ii) glabell-occipital length (\emph{největší délka mozkovny} in Czech),
  and data from three sites: Berg in Austria,
  Australia and Burjati in Siberia. Further, two dataframes are provided:
  \code{HowellsAll} which contains all measurements reported by Howells
  and \code{Howells} which is a balanced (with respect to gender and
  site) random subset of original data.  
}
\usage{
data(Howells)

data(HowellsAll)
}
\format{
  A \code{data.frame} with 240 rows (\code{Howells})/289 rows (\code{HowellsAll}) and the following variables.
  \describe{
    \item{gender}{gender, 0 = \emph{female}, 1 = \emph{male}}
    \item{popul}{population (site), 0 = \emph{Australia}, 1 = \emph{Berg
      in Austria}, 2 = \emph{Burjati in Siberia}}    
    \item{oca}{occipital angle}
    \item{gol}{glabell-occipital length}
    \item{fgender}{\code{factor} with levels \emph{F} and \emph{M}
      corresponding to the variable \code{gender}}
    \item{fpopul}{\code{factor} with levels \emph{AUSTR}, \emph{BERG}
      and \emph{BURIAT} corresponding to the variable \code{popul}}
    \item{fgen.pop}{\code{factor} obtained as \code{fgender:fpopul}}
    \item{fpop.gen}{\code{factor} obtained as \code{fpopul:fgender}}    
  }  
}
\source{
  \url{http://konig.la.utk.edu/howells.htm}
  
  \url{http://msekce.karlin.mff.cuni.cz/~zvara/regrese/kniha/R.ZIP}
}
\references{
  Howells, W. W. (1996).
  Howell's craniometric data on the internet.
  \emph{American Journal of Physical Anthropology}, \bold{101}(3),
  441-442, doi: 10.1002/ajpa.1331010302.  
  
  Zvára, K. (2008).
  \emph{Regrese}.
  Praha: Matfyzpress.
  ISBN 978-80-7378-041-8.
}
\examples{
data(Howells)
summary(Howells)

data(HowellsAll)
summary(HowellsAll)
}
\keyword{datasets}
