\name{Kojeni}
\alias{Kojeni}
\docType{data}
\title{Breast feeding data on 99 children}
\description{
  Data on 99 children born in two hospitals (in Prague and a certain
  province city in the Czech Republic) in the 90's of the 20th century.
  
  Data are used for several illustrations in the book \emph{Regrese}
  by Karel Zvára (Zvára, 2008). Originally, data were obtained
  by P. Hajná during preparation of her Master thesis with the breast
  feeding (\dQuote{kojení} in Czech) habits of Czech mothers as the
  primary research goal (Hajná, 1995).   
}
\usage{data(Kojeni)}
\format{
  A \code{data.frame} with 99 rows and the following variables.
  \describe{
    \item{bplace}{birth place of a child, 1 = \emph{Prague}, 2 =
      \emph{province city}}
    \item{n.child}{number of children of parents}
    \item{educ}{education of a mother, 1 = \emph{primary}, 2 =
      \emph{secondary}, 3 = \emph{tertiary}}
    \item{bfeed.dur}{breast feeding duration [weeks]. This variable is
      censored at 24 weeks, i.e., \code{bfeed.dur}\code{=}\code{24}
      means that mother was still giving a breast feeding at 24 weeks
      after birth of a child}
    \item{bfeed24}{was mother still giving a breast feeding at 24 weeks
      after birth? 1 = \emph{yes}, 0 = \emph{no}}
    \item{gender}{gender of a child, 1 = \emph{boy}, 0 = \emph{girl}}
    \item{bweight}{birth weight [g] of a child}
    \item{blength}{birth length [cm] of a child}
    \item{weight24}{weight [g] of a child at the age of 24 weeks}
    \item{length24}{length [cm] of a child at the age of 4 weeks}
    \item{breast}{was a child offered a breast soon after the birth? 1 = \emph{yes}, 0 = \emph{no}}
    \item{father}{was a father present at the delivery? 1 = \emph{yes}, 0 = \emph{no}}
    \item{teat}{was a child given a teat for most of the 24 weeks time? 1 = \emph{yes}, 0 = \emph{no}}
    \item{plan}{was a child planned? 1 = \emph{yes}, 0 = \emph{no}}
    \item{mheight}{mother's height [cm]}
    \item{fheight}{father's height [cm]}
    \item{mage}{mother's age}
    \item{fage}{father's age}
    \item{fbplace}{\code{factor} with levels
      \emph{Prague}/\emph{Province} corresponding to the variable \code{bplace}}
    \item{feduc}{\code{factor} with levels
      \emph{Primary}/\emph{Secondary}/\emph{Tertiary} corresponding to the variable \code{educ}}    
    \item{fbfeed24}{\code{factor} with levels \emph{No}/\emph{Yes} corresponding to the variable \code{bfeed24}}
    \item{fgender}{\code{factor} with levels \emph{Girl}/\emph{Boy} corresponding to the variable \code{gender}}    
    \item{fbreast}{\code{factor} with levels \emph{No}/\emph{Yes} corresponding to the variable \code{breast}}
    \item{ffather}{\code{factor} with levels \emph{No}/\emph{Yes} corresponding to the variable \code{father}}
    \item{fteat}{\code{factor} with levels \emph{No}/\emph{Yes} corresponding to the variable \code{teat}}
    \item{fplan}{\code{factor} with levels \emph{No}/\emph{Yes} corresponding to the variable \code{plan}}            
  }  
}
\source{
  \url{http://msekce.karlin.mff.cuni.cz/~zvara/regrese/kniha/R.ZIP}
}
\references{
  Hajná, P. (1995).
  \emph{Vliv biosociálních faktorů na délku kojení a závislost vybraných
  antropometrických charakteristik na způsob výživy dítěte v prvních
  šesti měsících života.}
  Diplomová práce, Přírodovědecká fakulta Univerzity Karlovy v Praze.
  
  Zvára, K. (2008).
  \emph{Regrese}.
  Praha: Matfyzpress.
  ISBN 978-80-7378-041-8.
}
\examples{
data(Kojeni)
summary(Kojeni)
}
\keyword{datasets}
